Place1TBS mandatory braces.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index b2db8a6a54097913ad2068c701533b34b8f66008..473ec6a0a591695ac5b7c095e41058b8d6e0e5d2 100644 (file)
--- a/score.c
+++ b/score.c
@@ -1,19 +1,19 @@
-#include <stdlib.h>
-#include "advent.h"
-#include "database.h"
-#include "newdb.h"
-
 /*
- * scoring and wrap-up
+ * Scoring and wrap-up.
+ *
+ * SPDX-FileCopyrightText: (C) 1977, 2005 by Will Crowther and Don Woods
+ * SPDX-License-Identifier: BSD-2-Clause
  */
+#include <stdlib.h>
+#include "advent.h"
+#include "dungeon.h"
 
-static long mxscor;    /* ugh..the price for having score() not exit. */
+static int mxscor;     /* ugh..the price for having score() not exit. */
 
-long score(enum termination mode)
+int score(enum termination mode) {
 /* mode is 'scoregame' if scoring, 'quitgame' if quitting, 'endgame' if died
  * or won */
-{
-    long score = 0;
+    int score = 0;
 
     /*  The present scoring algorithm is as follows:
      *     Objective:          Points:        Present total possible:
@@ -37,49 +37,68 @@ long score(enum termination mode)
     /*  First tally up the treasures.  Must be in building and not broken.
      *  Give the poor guy 2 points just for finding each treasure. */
     mxscor = 0;
-    for (long i = MINTRS; i <= MAXTRS; i++) {
-        if (object_descriptions[i].inventory != 0) {
-            long k = 12;
-            if (i == CHEST)k = 14;
-            if (i > CHEST)k = 16;
-            if (game.prop[i] >= 0)
+    for (int i = 1; i <= NOBJECTS; i++) {
+       if (!objects[i].is_treasure) {
+             continue;
+       }
+        if (objects[i].inventory != 0) {
+            int k = 12;
+            if (i == CHEST) {
+                k = 14;
+           }
+            if (i > CHEST) {
+                k = 16;
+           }
+            if (!PROP_IS_STASHED(i) && !PROP_IS_NOTFOUND(i)) {
                 score += 2;
-            if (game.place[i] == LOC_BUILDING && game.prop[i] == 0)
+           }
+            if (game.objects[i].place == LOC_BUILDING && PROP_IS_FOUND(i)) {
                 score += k - 2;
+           }
             mxscor += k;
         }
     }
 
/*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (maximum_deaths - game.numdie) * 10;
-    mxscor += maximum_deaths * 10;
-    if (mode == endgame)
+    score += (NDEATHS - game.numdie) * 10;
+    mxscor += NDEATHS * 10;
+    if (mode == endgame) {
         score += 4;
+    }
     mxscor += 4;
-    if (game.dflag != 0)score += 25;
+    if (game.dflag != 0) {
+        score += 25;
+    }
     mxscor += 25;
-    if (game.closng)score += 25;
+    if (game.closng) {
+        score += 25;
+    }
     mxscor += 25;
     if (game.closed) {
-        if (game.bonus == 0)
-            score += 10;
-        if (game.bonus == SPLATTER_MESSAGE)
-            score += 25;
-        if (game.bonus == DEFEAT_MESSAGE)
-            score += 30;
-        if (game.bonus == VICTORY_MESSAGE)
-            score += 45;
+       if (game.bonus == none) {
+             score += 10;
+       }
+       if (game.bonus == splatter) {
+             score += 25;
+       }
+       if (game.bonus == defeat) {
+             score += 30;
+       }
+       if (game.bonus == victory) {
+             score += 45;
+       }
     }
     mxscor += 45;
 
     /* Did he come to Witt's End as he should? */
-    if (game.place[MAGAZINE] == LOC_WITTSEND)
+    if (game.objects[MAGAZINE].place == LOC_WITTSEND) {
         score += 1;
+    }
     mxscor += 1;
 
     /* Round it off. */
@@ -87,14 +106,17 @@ long score(enum termination mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (long i = 1; i <= HINT_COUNT; i++) {
-        if (game.hinted[i])
-            score = score - hints[i-1].penalty;
+    for (int i = 0; i < NHINTS; i++) {
+       if (game.hints[i].used) {
+             score = score - hints[i].penalty;
+       }
     }
-    if (game.novice)
+    if (game.novice) {
         score -= 5;
-    if (game.clshnt)
+    }
+    if (game.clshnt) {
         score -= 10;
+    }
     score = score - game.trnluz - game.saved;
 
     /* Return to score command if that's where we came from. */
@@ -105,27 +127,34 @@ long score(enum termination mode)
     return score;
 }
 
-void terminate(enum termination mode)
+void terminate(enum termination mode) {
 /* End of game.  Let's tell him all about it. */
-{
-    long points = score(mode);
+    int points = score(mode);
+#if defined ADVENT_AUTOSAVE
+    autosave();
+#endif
 
-    if (points + game.trnluz + 1 >= mxscor && game.trnluz != 0)
+    if (points + game.trnluz + 1 >= mxscor && game.trnluz != 0) {
         rspeak(TOOK_LONG);
-    if (points + game.saved + 1 >= mxscor && game.saved != 0)
+    }
+    if (points + game.saved + 1 >= mxscor && game.saved != 0) {
         rspeak(WITHOUT_SUSPENDS);
+    }
     rspeak(TOTAL_SCORE, points, mxscor, game.turns, game.turns);
-    for (long i = 1; i <= (long)CLSSES; i++) {
+    for (int i = 1; i <= (int)NCLASSES; i++) {
         if (classes[i].threshold >= points) {
             speak(classes[i].message);
-            i = classes[i].threshold + 1 - points;
-            rspeak(NEXT_HIGHER, i, i);
-            exit(0);
+           if (i < (int)NCLASSES) {
+               int nxt = classes[i].threshold + 1 - points;
+               rspeak(NEXT_HIGHER, nxt, nxt);
+           } else {
+               rspeak(NO_HIGHER);
+           }
+            exit(EXIT_SUCCESS);
         }
     }
     rspeak(OFF_SCALE);
-    rspeak(NO_HIGHER);
-    exit(0);
+    exit(EXIT_SUCCESS);
 }
 
 /* end */
@@ -37,49 +37,68 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  maximum_deaths and
+    /*  Now look at how he finished and how far he got.  NDEATHS and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still